# -*- coding: utf-8 -*-
import dash
import dash_core_components as dcc
import dash_html_components as html
import plotly.graph_objs as go
from dash.dependencies import Input, Output

#~ Numpy and data treatment
import numpy as np
import io
#~ import pandas as pd
#~ from padas_datareader.data import DataReader
import time
import datetime as dt

#~ Dash 
app = dash.Dash()
server = app.server

markdown_text = '''
## Pressure Sensor Reading

### Concept 
This graph shows the pressure evolution with the input devices assignment, based on a custom made ADC with an Attiny84.
The Raspberry Pi creates a webserver with apache2, which, through mod_wsgi, runs a plotting interface based on plot.ly / dash.
The plot reads the data from a log.dat file, which is run with a crontab work every minute, in the Pi itself.

'''


app.layout = html.Div(children=[
    #~ html.H2(children='Example of header'),

    #~ html.Div(children='''
        #~ Example of Div
    #~ '''),
    
    dcc.Markdown(children=markdown_text),
    dcc.Graph(id='pressure-graph'),
    dcc.Interval(
        id='interval-component',
        interval=1*1000,
        n_intervals=0
    )
])

@app.callback(Output('pressure-graph','figure'),
    [Input('interval-component','n_intervals')])
def update_graph_live(n):
    dataVal=np.genfromtxt('/home/pi/Documents/Oscar/Fabacademy/SensorLogPlot/log.dat',delimiter=',')
    xvalues = range(len(dataVal))
    yvalues = dataVal[:,1]
    
    traces = list()
    traces.append(go.Scatter(
        x=xvalues,
        y=yvalues,
        name='Pressure'
        ))
    return {'data': traces}

#~ @app.callback(Output('pressure-graph','figure'),
    #~ [Input('interval-component','n_intervals')])
#~ def update_graph_live(n):
    #~ dataVal=np.genfromtxt('/home/pi/Documents/Oscar/Fabacademy/SensorLogPlot/log.dat',delimiter=',')
    #~ xvalues = range(len(dataVal))
    #~ yvalues = dataVal[:,1]
    
    #~ fig = go.Figure(
        #~ data=[
            #~ go.Scatter(
                #~ x=xvalues,
                #~ y=yvalues,
                #~ name='Pressure',
                #~ marker=go.Marker(
                    #~ color='rgb(255, 0, 0)'
                #~ )
            #~ ),
        #~ ],
        #~ layout=go.Layout(
            #~ title='Pressure Sensor Reading',
            #~ showlegend=True,
            #~ legend=go.Legend(
                #~ x=0,
                #~ y=1.0
            #~ ),
            #~ margin=go.Margin(l=80, r=40, t=40, b=80, pad=10),
            #~ autosize=True,
            #~ xaxis=dict(title='Date'),
            #~ yaxis=dict(title='Pressure (kPa)')
        #~ )
    #~ )
    
    #~ return fig
    
app.css.append_css({"external_url": "https://codepen.io/chriddyp/pen/bWLwgP.css"})

if __name__ == '__main__':
    app.run_server(debug=True, host='0.0.0.0', port=8082, threaded=True)


